<?php

error_log( "Configuration: configuration.php" );

define( "DOCUMENT_ROOT", $_SERVER["DOCUMENT_ROOT"]                     );
define(          "BASE", DOCUMENT_ROOT . "/DropSpace/latest/dropspace" );
define(   "COMMON_PATH", BASE . "/share/content/"                      );
define(    "SITES_PATH", DOCUMENT_ROOT . "/sites"                      );

$domain            = $_SERVER["SERVER_NAME"];
$sitename_reversed = DetermineSitenameReversed( $domain, SITES_PATH );
$sitename_natural  = DetermineSitename        ( $domain, SITES_PATH );
$sitename          = "XXX";

if ( file_exists( SITES_PATH . "/" . $sitename_reversed ) )
{
    $sitename = $sitename_reversed;
}
else
if ( file_exists( SITES_PATH . "/" . $sitename_natural  ) )
{
    $sitename = $sitename_natural;
}
else
{
    error_log( "Could not find directory for domain: $domain (checked $sitename_reversed and $sitename_natural)" );
    error_log( "Check that Dropbox directory is readable and executable by world - chmod +rw Dropbox" );
    exit;
}

error_log( "Site name:    $sitename" );

$content_path = DetermineContentPath( $sitename  );

error_log( "Content path: $content_path" );

define(  "CONTENT_PATH", $content_path                                 );
define(    "PAGES_PATH", DOCUMENT_ROOT . "/share/pages/$sitename"      );
define(  "CLIENT_STYLE", "$sitename"                                   );
define(     "RESOURCES", "/client/$sitename/resources"                 );

if ( str_contains( $_SERVER["SERVER_NAME"], "dropspace.local" ) )
{
	define( "DEBUG", true );
}

//  Remove dependency.
//
//include( BASE . "/dep/libpagecentric/configuration/initialisation.php" );

set_include_path( BASE . "/source/php" );

include_once( BASE . "/source/php/pagecentric.util/DBi.php"             );
include_once( BASE . "/source/php/pagecentric.util/HelperFunctions.php" );
include_once( BASE . "/lib/autoload.php"             );
include_once( BASE . "/lib/autoload_pagecentric.php" );

Page::initialise();

function BeginsWithTLD( $domain )
{
    return IsTLD( explode( ".", $domain )[0] );
}

function DetermineSitenameReversed( $domain, $sites_path )
{
    //  If .local domain (dropspace.org.local),
    //  will need to rearrange to be 'org.dropspace.local',
    //  so remove '.local', and make 'is_local' true.
    //
    $is_local = (FALSE !== strpos( $domain, ".local" ));
    $domain   = str_replace( ".local", "", $domain );

    $sitename = Reverse( $domain );                     // www.dropspace.org --> org.dropspace.www
    $sitename = str_replace( ".www", "", $sitename );   // org.dropspace.www --> org.dropspace

    if ( $is_local )
    {
        $sitename = "$sitename.local";                  // org.dropspace     --> org.dropspace.local
    }

    return $sitename;
}

function DetermineSitename( $domain, $sites_path )
{
	$sitename = "";
    $is_local = (FALSE !== strpos( $domain, ".local" ));
    $is_draft = (0     === strpos( $domain, "draft"  ));

    $sitename = $is_draft ? str_replace( "draft-www.", "", $domain ) : $domain;
    $sitename = $is_draft ? str_replace(     "draft.", "", $domain ) : $domain;

    $sitename = str_replace( "www.", "", $sitename );

    if ( $is_draft )
    {
        $sitename = $sitename . ".draft";
    }
	return $sitename;
}

function DetermineSitenameLegacy( $domain, $sites_path )
{
    $sitename = "";
    $is_local = (FALSE !== strpos( $domain, ".local" ));
    $is_draft = (0     === strpos( $domain, "draft"  ));

    $sitename = $is_draft ? str_replace( "draft-www.", "", $domain ) : $domain;
    $sitename = $is_draft ? str_replace(     "draft.", "", $domain ) : $domain;

    $sitename = str_replace( "www.", "", $sitename );

    if ( $is_draft )
    {
        $sitename = $sitename . ".draft";
    }

    if ( ! file_exists( $sites_path . "/" . $sitename ) )
    {
        $bits   = explode( '.', $sitename );

        foreach ( $bits as $part )
        {
            if ( ! IsGeneric( $part ) )
            {
                $sitename = $part;
                break;
            }
        }
        if ( $is_local ) $sitename = $sitename . ".local";
        if ( $is_draft ) $sitename = $sitename . ".draft";

        if ( ! file_exists( $sites_path . "/" . $sitename ) )
        {
            error_log( "Could not find directory for domain: $domain ($sitename)" );
            exit;
        }
    }

    error_log( "Accessing: $sitename for: $domain" );

    return $sitename;
}


function IsGeneric( $value )
{
	switch ( $value )
	{
	case "www":
		return true;

	default:
		return IsTLD( $value );
	}
}

function IsTLD( $value )
{
    switch ( $value )
    {
    case "au":
    case "com":
    case "net":
    case "online":
    case "org":
    case "xyz":
        return true;

    default:
        return false;
    }
}

function str_contains( $haystack, $needle )
{
	return (FALSE !== strpos( $haystack, $needle ));
}

function DetermineContentPath( $sitename )
{
    $content_path = "";

    if ( file_exists( SITES_PATH . "/$sitename/CONTENT_PATH" ) )
    {
        $provisional_path = file_get_contents( SITES_PATH . "/$sitename/CONTENT_PATH" );

        if ( FALSE === strpos( $provisional_path, ".." ) )
        {
            $content_path = trim( SITES_PATH . "/$sitename/$provisional_path" );
        }
    }
    else
    if ( file_exists( SITES_PATH . "/$sitename/_content/_index" ) )
    {
        $content_path = SITES_PATH . "/$sitename/_content";
    }
    else
    if ( file_exists( SITES_PATH . "/$sitename/share/content/_index" ) )
    {
        $content_path = SITES_PATH . "/$sitename/share/content";
    }
    else
    if ( file_exists( SITES_PATH . "/$sitename/source/content/_index" ) )
    {
        $content_path = SITES_PATH . "/$sitename/source/content";
    }
    else
    {
        $content_path = SITES_PATH . "/$sitename";
    }
    return $content_path;
}

function Reverse( $domain )
{
    $bits = explode( ".", $domain );
    $bits = array_reverse( $bits );

    return implode( ".", $bits );
}

?>
